@@ -40,6 +40,7 @@
 
 #define GEN_META_MODELICA_BUILTIN_BOXPTR
 #include "meta_modelica_builtin_boxptr.h"
+#include "../util/omc_numbers.h"
 
 metamodelica_string intString(modelica_integer i)
 {
@@ -99,7 +100,7 @@ modelica_real nobox_stringReal(threadData_t *threadData,metamodelica_string s)
   char *endptr,*str=MMC_STRINGDATA(s);
   MMC_CHECK_STRING(s);
   errno = 0;
-  res = strtod(str,&endptr);
+  res = om_strtod(str,&endptr);
   if (errno != 0 || str == endptr)
     MMC_THROW_INTERNAL();
   if (*endptr != '\0')
@@ -422,7 +423,21 @@ void boxptr_listSetFirst(threadData_t *threadData, modelica_metatype cellToDestr
   MMC_CAR(cellToDestroy) = newContent;
 }
 
-modelica_metatype listAppend(modelica_metatype l1,modelica_metatype l2)
+modelica_metatype listAppendDestroy(modelica_metatype lstFirstDestroyed, modelica_metatype listSecondKept)
+{
+  modelica_metatype lst = lstFirstDestroyed;
+  if (MMC_NILTEST(lstFirstDestroyed)) {
+    return listSecondKept;
+  }
+  while (!MMC_NILTEST(MMC_CDR(lst))) {
+    lst = MMC_CDR(lst);
+  }
+  /* reached the end, set the element */
+  MMC_CDR(lst) = listSecondKept;
+  return lstFirstDestroyed;
+}
+
+modelica_metatype listAppend(modelica_metatype l1, modelica_metatype l2)
 {
   int length = 0, i = 0;
   struct mmc_cons_struct *res = NULL;
@@ -434,7 +449,7 @@ modelica_metatype listAppend(modelica_metatype l1,modelica_metatype l2)
     return l2;
   res = (struct mmc_cons_struct*)mmc_alloc_words( length * 3 /*(sizeof(struct mmc_cons_struct)/sizeof(void*))*/ ); /* Do one single big alloc. It's cheaper */
   for (i=0; i<length-1; i++) { /* Write all except the last element... */
-    struct mmc_cons_struct *p = res+i;
+    p = res+i;
     p->header = MMC_STRUCTHDR(2, MMC_CONS_CTOR);
     p->data[0] = MMC_CAR(l1);
     p->data[1] = MMC_TAGPTR(res+i+1);
@@ -690,7 +705,7 @@ modelica_boolean setStackOverflowSignal(modelica_boolean inSignal)
   return inSignal;
 }
 
-#if defined(linux) || defined(__APPLE_CC__)
+#if defined(__linux__) || defined(__APPLE_CC__)
 #include <execinfo.h>
 metamodelica_string referenceDebugString(modelica_metatype fnptr)
 {
@@ -710,6 +725,14 @@ metamodelica_string referenceDebugString(modelica_metatype fnptr)
 }
 #endif
 
+metamodelica_string referencePointerString(modelica_metatype ptr)
+{
+  // 2 chars per byte + 3 for "0x" and null terminator.
+  char str[sizeof(void*)*2 + 3];
+  snprintf(str, sizeof(void*)*2 + 3, "%p", ptr);
+  return mmc_mk_scon(str);
+}
+
 const char* SourceInfo_SOURCEINFO__desc__fields[7] = {"fileName","isReadOnly","lineNumberStart","columnNumberStart","lineNumberEnd","columnNumberEnd","lastEditTime"};
 struct record_description SourceInfo_SOURCEINFO__desc = {
   "SourceInfo_SOURCEINFO",
