@@ -38,6 +38,7 @@
 #include "../util/omc_mmap.h"
 #include "../util/omc_numbers.h"
 #include "solver/model_help.h"
+#include "../util/omc_file.h"
 
 static inline const char* skipSpace(const char* str)
 {
@@ -373,6 +374,26 @@ static void readInfoJson(const char *str,MODEL_DATA_XML *xml)
 
 void modelInfoInit(MODEL_DATA_XML* xml)
 {
+  omc_stat_t buf = {0};
+  // check for file exists, as --fmiFilter=blackBox or protected will not export the _info.json file
+  int fileStatus;
+  if (omc_flag[FLAG_INPUT_PATH])
+  {
+    const char *jsonFile;
+    GC_asprintf(&jsonFile, "%s/%s", omc_flagValue[FLAG_INPUT_PATH], xml->fileName);
+    fileStatus = omc_stat(jsonFile, &buf);
+  }
+  else
+  {
+    fileStatus = omc_stat(xml->fileName, &buf);
+  }
+
+  if (fileStatus != 0)
+  {
+    xml->fileName = NULL;
+    return;
+  }
+
 #if !defined(OMC_NO_FILESYSTEM)
   omc_mmap_read mmap_reader = {0};
 #endif
@@ -425,6 +446,13 @@ void modelInfoDeinit(MODEL_DATA_XML* xml)
 
 FUNCTION_INFO modelInfoGetFunction(MODEL_DATA_XML* xml, size_t ix)
 {
+  /* check for xml->fileName == NULL for --fmiFilter=blackBox and protected
+   * and return dummy function info to make the fmu's simulation work, as
+   * the _json.info will not be exported for the above --fmiFilter combinations
+  */
+  if (xml->fileName == NULL)
+    return modelInfoGetDummyFunction(xml);
+
   if(xml->functionNames == NULL)
   {
     modelInfoInit(xml);
@@ -433,8 +461,28 @@ FUNCTION_INFO modelInfoGetFunction(MODEL_DATA_XML* xml, size_t ix)
   return xml->functionNames[ix];
 }
 
+FUNCTION_INFO modelInfoGetDummyFunction(MODEL_DATA_XML* xml)
+{
+  FUNCTION_INFO functionInfo = omc_dummyFunctionInfo;
+  return functionInfo;
+}
+
+EQUATION_INFO modelInfoGetDummyEquation(MODEL_DATA_XML* xml)
+{
+  const char * var = "";
+  EQUATION_INFO equationInfo = {-1, 0, 0, -1, &var}; // omc_dummyEquationInfo is not working in mingw
+  return equationInfo;
+}
+
 EQUATION_INFO modelInfoGetEquation(MODEL_DATA_XML* xml, size_t ix)
 {
+  /* check for xml->fileName == NULL for --fmiFilter=blackBox and protected
+   * and return dummy equation info to make the fmu's simulation work, as
+   * the _json.info will not be exported for the above --fmiFilter combinations
+  */
+  if (xml->fileName == NULL)
+    return modelInfoGetDummyEquation(xml);
+
   if (xml->equationInfo == NULL) {
     modelInfoInit(xml);
   }
@@ -444,6 +492,13 @@ EQUATION_INFO modelInfoGetEquation(MODEL_DATA_XML* xml, size_t ix)
 
 EQUATION_INFO modelInfoGetEquationIndexByProfileBlock(MODEL_DATA_XML* xml, size_t ix)
 {
+  /* check for xml->fileName == NULL for --fmiFilter=blackBox and protected
+   * and return dummy equation info to make the fmu's simulation work, as
+   * the _json.info will not be exported for the above --fmiFilter combinations
+  */
+  if (xml->fileName == NULL)
+    return modelInfoGetDummyEquation(xml);
+
   int i;
   if(xml->equationInfo == NULL)
   {
