@@ -542,16 +542,28 @@ int startNonInteractiveSimulation(int argc, char**argv, DATA* data, threadData_t
     init_initMethod = omc_flagValue[FLAG_IIM];
   }
   if(omc_flag[FLAG_IIF]) {
+    omc_stat_t attrib;
     if (omc_flag[FLAG_INPUT_PATH]) {
       const char *tmp_filename;
-      if (0 > GC_asprintf(&tmp_filename, "%s/%s", omc_flagValue[FLAG_INPUT_PATH], omc_flagValue[FLAG_IIF])) {
-        throwStreamPrint(NULL, "simulation_runtime.cpp: Error: can not allocate memory.");
+
+      if (omc_stat(omc_flagValue[FLAG_IIF], &attrib ) == 0) {
+        if (0 > GC_asprintf(&tmp_filename, "%s", omc_flagValue[FLAG_IIF] )) {
+          throwStreamPrint(NULL, "simulation_runtime.cpp: Error: can not allocate memory.");
+        }
+      }
+      else {
+        if (0 > GC_asprintf(&tmp_filename, "%s/%s", omc_flagValue[FLAG_INPUT_PATH], omc_flagValue[FLAG_IIF])) {
+          throwStreamPrint(NULL, "simulation_runtime.cpp: Error: can not allocate memory.");
+        }
       }
       init_file = tmp_filename;
     }
     else {
       init_file = omc_flagValue[FLAG_IIF];
     }
+    if (omc_stat(init_file.c_str(), &attrib ) != 0) {
+      throwStreamPrint(NULL, "Initialization file \"%s\" doesn't exist.", init_file.c_str());
+    }
   }
   if(omc_flag[FLAG_IIT]) {
     init_time_string = omc_flagValue[FLAG_IIT];
@@ -595,12 +607,20 @@ int startNonInteractiveSimulation(int argc, char**argv, DATA* data, threadData_t
     alarm(0);
   }
 
-  if(0 == retVal && omc_flag[FLAG_DATA_RECONCILE])
+  if (omc_flag[FLAG_DATA_RECONCILE])
   {
-  infoStreamPrint(LOG_STDOUT, 0, "DataReconciliation Starting!");
-  infoStreamPrint(LOG_STDOUT, 0, "%s", data->modelData->modelName);
-  retVal = dataReconciliation(data, threadData);
-  infoStreamPrint(LOG_STDOUT, 0, "DataReconciliation Completed!");
+    infoStreamPrint(LOG_STDOUT, 0, "DataReconciliation Starting!");
+    infoStreamPrint(LOG_STDOUT, 0, "%s", data->modelData->modelName);
+    retVal = dataReconciliation(data, threadData, retVal);
+    infoStreamPrint(LOG_STDOUT, 0, "DataReconciliation Completed!");
+  }
+
+  if (omc_flag[FLAG_DATA_RECONCILE_BOUNDARY])
+  {
+    infoStreamPrint(LOG_STDOUT, 0, "Reconcile Boundary Conditions Starting!");
+    infoStreamPrint(LOG_STDOUT, 0, "%s", data->modelData->modelName);
+    retVal = reconcileBoundaryConditions(data, threadData, retVal);
+    infoStreamPrint(LOG_STDOUT, 0, "Reconcile Boundary Conditions Completed!");
   }
 
   if(0 == retVal && create_linearmodel) {
@@ -745,6 +765,7 @@ static int callSolver(DATA* simData, threadData_t *threadData, string init_initM
     if (compiledInDAEMode)
     {
       simData->callback->functionDAE = evaluateDAEResiduals_wrapperEventUpdate;
+      simData->callback->function_ZeroCrossingsEquations = evaluateDAEResiduals_wrapperZeroCrossingsEquations;
     }
   }
 
@@ -825,12 +846,12 @@ int initRuntimeAndSimulation(int argc, char**argv, DATA *data, threadData_t *thr
     }
 
     messageClose(LOG_STDOUT);
-    EXIT(0);
+    EXIT(1);
   }
 
-  if(omc_flag[FLAG_HELP]) {
+  if(omc_flag[FLAG_HELP])
+  {
     std::string option = omc_flagValue[FLAG_HELP];
-
     for(i=1; i<FLAG_MAX; ++i)
     {
       if(option == std::string(FLAG_NAME[i]))
@@ -915,7 +936,7 @@ int initRuntimeAndSimulation(int argc, char**argv, DATA *data, threadData_t *thr
 
     warningStreamPrint(LOG_STDOUT, 0, "invalid command line option: -help=%s", option.c_str());
     warningStreamPrint(LOG_STDOUT, 0, "use %s -help for a list of all command-line flags", argv[0]);
-    EXIT(0);
+    EXIT(1);
   }
 
   setGlobalVerboseLevel(argc, argv);
@@ -927,13 +948,13 @@ int initRuntimeAndSimulation(int argc, char**argv, DATA *data, threadData_t *thr
     EXIT(1);
   }
 
-  readFlag(&data->simulationInfo->nlsMethod, NLS_MAX, omc_flagValue[FLAG_NLS], "-nls", NLS_NAME, NLS_DESC);
-  readFlag(&data->simulationInfo-> lsMethod,  LS_MAX, omc_flagValue[FLAG_LS ],  "-ls",  LS_NAME,  LS_DESC);
-  readFlag(&data->simulationInfo->lssMethod, LSS_MAX, omc_flagValue[FLAG_LSS], "-lss", LSS_NAME, LSS_DESC);
-  readFlag(&homBacktraceStrategy, HOM_BACK_STRAT_MAX, omc_flagValue[FLAG_HOMOTOPY_BACKTRACE_STRATEGY], "-homBacktraceStrategy", HOM_BACK_STRAT_NAME, HOM_BACK_STRAT_DESC);
-  readFlag(&data->simulationInfo->newtonStrategy, NEWTON_MAX, omc_flagValue[FLAG_NEWTON_STRATEGY], "-newton", NEWTONSTRATEGY_NAME, NEWTONSTRATEGY_DESC);
+  readFlag((int*)&data->simulationInfo->nlsMethod, NLS_MAX, omc_flagValue[FLAG_NLS], "-nls", NLS_NAME, NLS_DESC);
+  readFlag((int*)&data->simulationInfo-> lsMethod,  LS_MAX, omc_flagValue[FLAG_LS ],  "-ls",  LS_NAME,  LS_DESC);
+  readFlag((int*)&data->simulationInfo->lssMethod, LSS_MAX, omc_flagValue[FLAG_LSS], "-lss", LSS_NAME, LSS_DESC);
+  readFlag((int*)&homBacktraceStrategy, HOM_BACK_STRAT_MAX, omc_flagValue[FLAG_HOMOTOPY_BACKTRACE_STRATEGY], "-homBacktraceStrategy", HOM_BACK_STRAT_NAME, HOM_BACK_STRAT_DESC);
+  readFlag((int*)&data->simulationInfo->newtonStrategy, NEWTON_MAX, omc_flagValue[FLAG_NEWTON_STRATEGY], "-newton", NEWTONSTRATEGY_NAME, NEWTONSTRATEGY_DESC);
   data->simulationInfo->nlsCsvInfomation = omc_flag[FLAG_NLS_INFO];
-  readFlag(&data->simulationInfo->nlsLinearSolver, NLS_LS_MAX, omc_flagValue[FLAG_NLS_LS], "-nlsLS", NLS_LS_METHOD, NLS_LS_METHOD_DESC);
+  readFlag((int*)&data->simulationInfo->nlsLinearSolver, NLS_LS_MAX, omc_flagValue[FLAG_NLS_LS], "-nlsLS", NLS_LS_METHOD, NLS_LS_METHOD_DESC);
 
   if(omc_flag[FLAG_HOMOTOPY_ADAPT_BEND]) {
     homAdaptBend = atof(omc_flagValue[FLAG_HOMOTOPY_ADAPT_BEND]);
@@ -1001,15 +1022,15 @@ int initRuntimeAndSimulation(int argc, char**argv, DATA *data, threadData_t *thr
   }
   if(omc_flag[FLAG_LSS_MIN_SIZE]) {
     linearSparseSolverMinSize = atoi(omc_flagValue[FLAG_LSS_MIN_SIZE]);
-    infoStreamPrint(LOG_STDOUT, 0, "Maximum system size for using linear sparse solver changed to %d", linearSparseSolverMinSize);
+    infoStreamPrint(LOG_STDOUT, 0, "Minimum system size for using linear sparse solver changed to %d", linearSparseSolverMinSize);
   }
-  if(omc_flag[FLAG_NLS_MAX_DENSITY]) {
-    nonlinearSparseSolverMaxDensity = atof(omc_flagValue[FLAG_NLS_MAX_DENSITY]);
+  if(omc_flag[FLAG_NLSS_MAX_DENSITY]) {
+    nonlinearSparseSolverMaxDensity = atof(omc_flagValue[FLAG_NLSS_MAX_DENSITY]);
     infoStreamPrint(LOG_STDOUT, 0, "Maximum density for using non-linear sparse solver changed to %f", nonlinearSparseSolverMaxDensity);
   }
-  if(omc_flag[FLAG_NLS_MIN_SIZE]) {
-    nonlinearSparseSolverMinSize = atoi(omc_flagValue[FLAG_NLS_MIN_SIZE]);
-    infoStreamPrint(LOG_STDOUT, 0, "Maximum system size for using non-linear sparse solver changed to %d", nonlinearSparseSolverMinSize);
+  if(omc_flag[FLAG_NLSS_MIN_SIZE]) {
+    nonlinearSparseSolverMinSize = atoi(omc_flagValue[FLAG_NLSS_MIN_SIZE]);
+    infoStreamPrint(LOG_STDOUT, 0, "Minimum system size for using non-linear sparse solver changed to %d", nonlinearSparseSolverMinSize);
   }
   if(omc_flag[FLAG_NEWTON_XTOL]) {
     newtonXTol = atof(omc_flagValue[FLAG_NEWTON_XTOL]);
@@ -1140,10 +1161,9 @@ int _main_SimulationRuntime(int argc, char**argv, DATA *data, threadData_t *thre
    */
   wchar_t** wargv = CommandLineToArgvW(GetCommandLineW(), &argc);
   for (int i = 0; i < argc; i++) {
-    WIDECHAR_TO_MULTIBYTE_LENGTH(wargv[i], len);
-    WIDECHAR_TO_MULTIBYTE_VAR(wargv[i], buf, len);
+    char* buf = omc_wchar_to_multibyte_str(wargv[i]);
     strcpy(argv[i], buf);
-    MULTIBYTE_OR_WIDECHAR_VAR_FREE(buf);
+    free(buf);
   }
 #endif
 
