@@ -407,7 +407,7 @@ void LineAnnotation::parseShapeAnnotation(QString annotation)
   }
   mPoints.clear();
   // 4th item of list contains the points.
-  QStringList pointsList = StringHandler::getStrings(StringHandler::removeFirstLastCurlBrackets(list.at(3)));
+  QStringList pointsList = StringHandler::getStrings(StringHandler::removeFirstLastCurlBrackets(stripDynamicSelect(list.at(3))));
   foreach (QString point, pointsList) {
     QStringList linePoints = StringHandler::getStrings(StringHandler::removeFirstLastCurlBrackets(point));
     if (linePoints.size() >= 2) {
@@ -415,28 +415,21 @@ void LineAnnotation::parseShapeAnnotation(QString annotation)
     }
   }
   // 5th item of list contains the color.
-  QStringList colorList = StringHandler::getStrings(StringHandler::removeFirstLastCurlBrackets(list.at(4)));
-  if (colorList.size() >= 3) {
-    int red, green, blue = 0;
-    red = colorList.at(0).toInt();
-    green = colorList.at(1).toInt();
-    blue = colorList.at(2).toInt();
-    mLineColor = QColor (red, green, blue);
-  }
+  mLineColor.parse(list.at(4));
   // 6th item of list contains the Line Pattern.
-  mLinePattern = StringHandler::getLinePatternType(list.at(5));
+  mLinePattern = StringHandler::getLinePatternType(stripDynamicSelect(list.at(5)));
   // 7th item of list contains the Line thickness.
-  mLineThickness = list.at(6).toFloat();
+  mLineThickness.parse(list.at(6));
   // 8th item of list contains the Line Arrows.
-  QStringList arrowList = StringHandler::getStrings(StringHandler::removeFirstLastCurlBrackets(list.at(7)));
+  QStringList arrowList = StringHandler::getStrings(StringHandler::removeFirstLastCurlBrackets(stripDynamicSelect(list.at(7))));
   if (arrowList.size() >= 2) {
     mArrow.replace(0, StringHandler::getArrowType(arrowList.at(0)));
     mArrow.replace(1, StringHandler::getArrowType(arrowList.at(1)));
   }
   // 9th item of list contains the Line Arrow Size.
-  mArrowSize = list.at(8).toFloat();
+  mArrowSize.parse(list.at(8));
   // 10th item of list contains the smooth.
-  mSmooth = StringHandler::getSmoothType(list.at(9));
+  mSmooth = StringHandler::getSmoothType(stripDynamicSelect(list.at(9)));
 }
 
 QPainterPath LineAnnotation::getShape() const
@@ -489,22 +482,19 @@ void LineAnnotation::paint(QPainter *painter, const QStyleOptionGraphicsItem *op
 {
   Q_UNUSED(option);
   Q_UNUSED(widget);
-  if (mVisible || !mDynamicVisible.isEmpty()) {
+  if (mVisible) {
     if (mLineType == LineAnnotation::TransitionType && mpGraphicsView->isVisualizationView()) {
       if (isActiveState()) {
         painter->setOpacity(1.0);
       } else {
         painter->setOpacity(0.2);
       }
-    } else if (!mDynamicVisibleValue && ((mpGraphicsView && mpGraphicsView->isVisualizationView())
-                                         || (mpParentComponent && mpParentComponent->getGraphicsView()->isVisualizationView()))) {
-      return;
     }
-    drawLineAnnotaion(painter);
+    drawLineAnnotation(painter);
   }
 }
 
-void LineAnnotation::drawLineAnnotaion(QPainter *painter)
+void LineAnnotation::drawLineAnnotation(QPainter *painter)
 {
   applyLinePattern(painter);
   // draw start arrow
@@ -728,24 +718,18 @@ QString LineAnnotation::getOMCShapeAnnotation()
     annotationString.append(pointsString);
   }
   // get the line color
-  QString colorString;
-  colorString.append("{");
-  colorString.append(QString::number(mLineColor.red())).append(",");
-  colorString.append(QString::number(mLineColor.green())).append(",");
-  colorString.append(QString::number(mLineColor.blue()));
-  colorString.append("}");
-  annotationString.append(colorString);
+  annotationString.append(mLineColor.toQString());
   // get the line pattern
   annotationString.append(StringHandler::getLinePatternString(mLinePattern));
   // get the thickness
-  annotationString.append(QString::number(mLineThickness));
+  annotationString.append(mLineThickness.toQString());
   // get the start and end arrow
   QString arrowString;
   arrowString.append("{").append(StringHandler::getArrowString(mArrow.at(0))).append(",");
   arrowString.append(StringHandler::getArrowString(mArrow.at(1))).append("}");
   annotationString.append(arrowString);
   // get the arrow size
-  annotationString.append(QString::number(mArrowSize));
+  annotationString.append(mArrowSize.toQString());
   // get the smooth
   annotationString.append(StringHandler::getSmoothString(mSmooth));
   return annotationString.join(",");
@@ -787,22 +771,16 @@ QString LineAnnotation::getShapeAnnotation()
     annotationString.append(pointsString);
   }
   // get the line color
-  if (mLineColor != Qt::black) {
-    QString colorString;
-    colorString.append("color={");
-    colorString.append(QString::number(mLineColor.red())).append(",");
-    colorString.append(QString::number(mLineColor.green())).append(",");
-    colorString.append(QString::number(mLineColor.blue()));
-    colorString.append("}");
-    annotationString.append(colorString);
+  if (mLineColor.isDynamicSelectExpression() || mLineColor != Qt::black) {
+    annotationString.append(QString("color=%1").arg(mLineColor.toQString()));
   }
   // get the line pattern
   if (mLinePattern != StringHandler::LineSolid) {
     annotationString.append(QString("pattern=").append(StringHandler::getLinePatternString(mLinePattern)));
   }
   // get the thickness
-  if (mLineThickness != 0.25) {
-    annotationString.append(QString("thickness=").append(QString::number(mLineThickness)));
+  if (mLineThickness.isDynamicSelectExpression() || mLineThickness != 0.25) {
+    annotationString.append(QString("thickness=%1").arg(mLineThickness.toQString()));
   }
   // get the start and end arrow
   if ((mArrow.at(0) != StringHandler::ArrowNone) || (mArrow.at(1) != StringHandler::ArrowNone)) {
@@ -813,8 +791,8 @@ QString LineAnnotation::getShapeAnnotation()
     annotationString.append(arrowString);
   }
   // get the arrow size
-  if (mArrowSize != 3) {
-    annotationString.append(QString("arrowSize=").append(QString::number(mArrowSize)));
+  if (mArrowSize.isDynamicSelectExpression() || mArrowSize != 3) {
+    annotationString.append(QString("arrowSize=%1").arg(mArrowSize.toQString()));
   }
   // get the smooth
   if (mSmooth != StringHandler::SmoothNone) {
@@ -961,8 +939,8 @@ void LineAnnotation::updateEndPoint(QPointF point)
       */
     if (mPoints.size() == 2 && mpEndComponent) {
       // just check if additional points are really needed or not.
-      if ((mGeometries[secondLastIndex] == ShapeAnnotation::HorizontalLine && mPoints[lastIndex].y() != point.y()) ||
-          (mGeometries[secondLastIndex] == ShapeAnnotation::VerticalLine && mPoints[lastIndex].x() != point.x())) {
+      if (secondLastIndex < mGeometries.size() && ((mGeometries.at(secondLastIndex) == ShapeAnnotation::HorizontalLine && mPoints.at(lastIndex).y() != point.y()) ||
+                                                   (mGeometries.at(secondLastIndex) == ShapeAnnotation::VerticalLine && mPoints.at(lastIndex).x() != point.x()))) {
         insertPointsGeometriesAndCornerItems(lastIndex);
         setCornerItemsActiveOrPassive();
         lastIndex = mPoints.size() - 1;
@@ -974,13 +952,14 @@ void LineAnnotation::updateEndPoint(QPointF point)
       mPoints.back() = point;
       updateCornerItem(lastIndex);
       /* update the 2nd point */
-      assert(secondLastIndex < mGeometries.size());
-      if (mGeometries[secondLastIndex] == ShapeAnnotation::HorizontalLine) {
-        mPoints[secondLastIndex] = QPointF(mPoints[secondLastIndex].x(), mPoints[secondLastIndex].y() + dy);
-      } else if (mGeometries[secondLastIndex] == ShapeAnnotation::VerticalLine) {
-        mPoints[secondLastIndex] = QPointF(mPoints[secondLastIndex].x() + dx, mPoints[secondLastIndex].y());
+      if (secondLastIndex < mGeometries.size()) {
+        if (mGeometries.at(secondLastIndex) == ShapeAnnotation::HorizontalLine) {
+          mPoints[secondLastIndex] = QPointF(mPoints.at(secondLastIndex).x(), mPoints.at(secondLastIndex).y() + dy);
+        } else if (mGeometries.at(secondLastIndex) == ShapeAnnotation::VerticalLine) {
+          mPoints[secondLastIndex] = QPointF(mPoints.at(secondLastIndex).x() + dx, mPoints.at(secondLastIndex).y());
+        }
+        updateCornerItem(secondLastIndex);
       }
-      updateCornerItem(secondLastIndex);
     }
     if (!mpGraphicsView->isCreatingConnection() && !mpGraphicsView->isCreatingTransition()) {
       removeRedundantPointsGeometriesAndCornerItems();
@@ -1012,18 +991,21 @@ void LineAnnotation::updateTransitionTextPosition()
 }
 
 /*!
-  Sets the shape flags.
-  */
+ * \brief LineAnnotation::setShapeFlags
+ * Sets the shape flags.
+ * \param enable
+ */
 void LineAnnotation::setShapeFlags(bool enable)
 {
-  if ((mLineType == LineAnnotation::ConnectionType || mLineType == LineAnnotation::TransitionType || mLineType == LineAnnotation::ShapeType)
+  if ((mLineType == LineAnnotation::ConnectionType || mLineType == LineAnnotation::TransitionType
+       || mLineType == LineAnnotation::InitialStateType || mLineType == LineAnnotation::ShapeType)
       && mpGraphicsView) {
-    /*
-      Only set the ItemIsMovable & ItemSendsGeometryChanges flags on Line if the class is not a system library class
-      AND Line is not an inherited Line AND Line type is not ConnectionType.
-      */
+    /* Only set the ItemIsMovable & ItemSendsGeometryChanges flags on Line if the class is not a system library class
+     * AND not a visualization view
+     * AND Line is not an inherited Line AND Line type is not ConnectionType.
+     */
     bool isSystemLibrary = mpGraphicsView->getModelWidget()->getLibraryTreeItem()->isSystemLibrary();
-    if (!isSystemLibrary && !isInheritedShape() && mLineType != LineAnnotation::ConnectionType &&
+    if (!isSystemLibrary && !mpGraphicsView->isVisualizationView() && !isInheritedShape() && mLineType != LineAnnotation::ConnectionType &&
         mLineType != LineAnnotation::TransitionType && mLineType != LineAnnotation::InitialStateType) {
       setFlag(QGraphicsItem::ItemIsMovable, enable);
       setFlag(QGraphicsItem::ItemSendsGeometryChanges, enable);
@@ -1266,9 +1248,9 @@ void LineAnnotation::updateConnectionTransformation()
   /* If both start and end component are selected then this function is called twice.
    * we use the flag mStartAndEndComponentSelected to make sure that we only use this function once in such case.
    */
-  if (!mStartAndEndComponentsSelected
-      && mpStartComponent && mpStartComponent->getRootParentComponent()->isSelected()
-      && mpEndComponent && mpEndComponent->getRootParentComponent()->isSelected()) {
+  if (mpStartComponent && mpStartComponent->getRootParentComponent()->isSelected()
+      && mpEndComponent && mpEndComponent->getRootParentComponent()->isSelected()
+      && mpStartComponent->getRootParentComponent() != mpEndComponent->getRootParentComponent() && !mStartAndEndComponentsSelected) {
       mStartAndEndComponentsSelected = true;
       return;
   } else if (mStartAndEndComponentsSelected) {
@@ -1278,16 +1260,17 @@ void LineAnnotation::updateConnectionTransformation()
   if (mpGraphicsView->getModelWidget()->getLibraryTreeItem()->getLibraryType() == LibraryTreeItem::OMS) {
     updateOMSConnection();
   } else {
-    assert(!mOldAnnotation.isEmpty());
-    if (mLineType == LineAnnotation::ConnectionType) {
-      mpGraphicsView->getModelWidget()->getUndoStack()->push(new UpdateConnectionCommand(this, mOldAnnotation, getOMCShapeAnnotation()));
-    } else if (mLineType == LineAnnotation::TransitionType) {
-      mpGraphicsView->getModelWidget()->getUndoStack()->push(new UpdateTransitionCommand(this, mCondition, mImmediate, mReset,
-                                                                                         mSynchronize, mPriority, mOldAnnotation,
-                                                                                         mCondition, mImmediate, mReset, mSynchronize,
-                                                                                         mPriority, getOMCShapeAnnotation()));
-    } else if (mLineType == LineAnnotation::InitialStateType) {
-      mpGraphicsView->getModelWidget()->getUndoStack()->push(new UpdateInitialStateCommand(this, mOldAnnotation, getOMCShapeAnnotation()));
+    if (!mOldAnnotation.isEmpty()) {
+      if (mLineType == LineAnnotation::ConnectionType) {
+        mpGraphicsView->getModelWidget()->getUndoStack()->push(new UpdateConnectionCommand(this, mOldAnnotation, getOMCShapeAnnotation()));
+      } else if (mLineType == LineAnnotation::TransitionType) {
+        mpGraphicsView->getModelWidget()->getUndoStack()->push(new UpdateTransitionCommand(this, mCondition, mImmediate, mReset,
+                                                                                           mSynchronize, mPriority, mOldAnnotation,
+                                                                                           mCondition, mImmediate, mReset, mSynchronize,
+                                                                                           mPriority, getOMCShapeAnnotation()));
+      } else if (mLineType == LineAnnotation::InitialStateType) {
+        mpGraphicsView->getModelWidget()->getUndoStack()->push(new UpdateInitialStateCommand(this, mOldAnnotation, getOMCShapeAnnotation()));
+      }
     }
   }
 }
@@ -1615,7 +1598,7 @@ Qt::ItemFlags ExpandableConnectorTreeModel::flags(const QModelIndex &index) cons
       (pExpandableConnectorTreeItem->parent() && pExpandableConnectorTreeItem->parent()->getRestriction() == StringHandler::ExpandableConnector))) {
     return Qt::ItemIsEnabled | Qt::ItemIsSelectable;
   } else {
-    return 0;
+    return Qt::ItemFlags();
   }
 }
 
@@ -1651,33 +1634,29 @@ QModelIndex ExpandableConnectorTreeModel::expandableConnectorTreeItemIndex(const
   return expandableConnectorTreeItemIndexHelper(pExpandableConnectorTreeItem, mpRootExpandableConnectorTreeItem, QModelIndex());
 }
 
-void ExpandableConnectorTreeModel::createExpandableConnectorTreeItem(Element *pComponent,
-                                                                     ExpandableConnectorTreeItem *pParentExpandableConnectorTreeItem)
+void ExpandableConnectorTreeModel::createExpandableConnectorTreeItem(Element *pComponent, ExpandableConnectorTreeItem *pParentExpandableConnectorTreeItem)
 {
   StringHandler::ModelicaClasses restriction = StringHandler::Model;
   if (pComponent->getLibraryTreeItem()) {
     restriction = pComponent->getLibraryTreeItem()->getRestriction();
   }
-  ExpandableConnectorTreeItem *pExpandableConnectorTreeItem = new ExpandableConnectorTreeItem(pComponent->getName(),
-                                                                                              pComponent->getComponentInfo()->isArray(),
-                                                                                              pComponent->getComponentInfo()->getArrayIndex(),
-                                                                                              restriction, false,
+  ExpandableConnectorTreeItem *pExpandableConnectorTreeItem = new ExpandableConnectorTreeItem(pComponent->getName(), pComponent->getComponentInfo()->isArray(),
+                                                                                              pComponent->getComponentInfo()->getArrayIndex(), restriction, false,
                                                                                               pParentExpandableConnectorTreeItem);
   int row = pParentExpandableConnectorTreeItem->getChildren().size();
   QModelIndex index = expandableConnectorTreeItemIndex(pParentExpandableConnectorTreeItem);
   beginInsertRows(index, row, row);
   pParentExpandableConnectorTreeItem->insertChild(row, pExpandableConnectorTreeItem);
   endInsertRows();
-  if (pComponent->getLibraryTreeItem()) {
+  if (pComponent->getLibraryTreeItem() && pComponent->getLibraryTreeItem()->getModelWidget()) {
     foreach (Element *pChildComponent, pComponent->getLibraryTreeItem()->getModelWidget()->getDiagramGraphicsView()->getElementsList()) {
       createExpandableConnectorTreeItem(pChildComponent, pExpandableConnectorTreeItem);
     }
   }
   // create add variable item only if item is expandable connector
   if (pExpandableConnectorTreeItem->getRestriction() == StringHandler::ExpandableConnector) {
-    ExpandableConnectorTreeItem *pNewVariableExpandableConnectorTreeItem = new ExpandableConnectorTreeItem(Helper::newVariable, false, "",
-                                                                                                           StringHandler::Model, true,
-                                                                                                           pExpandableConnectorTreeItem);
+    ExpandableConnectorTreeItem *pNewVariableExpandableConnectorTreeItem = new ExpandableConnectorTreeItem(Helper::newVariable, false, "", StringHandler::Model,
+                                                                                                           true, pExpandableConnectorTreeItem);
     int row = pExpandableConnectorTreeItem->getChildren().size();
     QModelIndex index = expandableConnectorTreeItemIndex(pExpandableConnectorTreeItem);
     beginInsertRows(index, row, row);
@@ -1751,7 +1730,7 @@ CreateConnectionDialog::CreateConnectionDialog(GraphicsView *pGraphicsView, Line
   // Start expandable connector treeview
   mpStartExpandableConnectorTreeView = 0;
   mpStartComponent = mpConnectionLineAnnotation->getStartComponent();
-  mpStartRootComponent = mpStartComponent->getParentComponent() ? mpStartComponent->getRootParentComponent() : 0;
+  mpStartRootComponent = mpStartComponent->getParentComponent() ? mpStartComponent->getRootParentComponent() : mpStartComponent;
   if (mpStartComponent->isExpandableConnector() || (mpStartRootComponent && mpStartRootComponent->isExpandableConnector())) {
     mpStartExpandableConnectorTreeModel = new ExpandableConnectorTreeModel(this);
     mpStartExpandableConnectorTreeProxyModel = new ExpandableConnectorTreeProxyModel(this);
@@ -1767,7 +1746,7 @@ CreateConnectionDialog::CreateConnectionDialog(GraphicsView *pGraphicsView, Line
   }
   // End expandable connector treeview
   mpEndComponent = mpConnectionLineAnnotation->getEndComponent();
-  mpEndRootComponent = mpEndComponent->getParentComponent() ? mpEndComponent->getRootParentComponent() : 0;
+  mpEndRootComponent = mpEndComponent->getParentComponent() ? mpEndComponent->getRootParentComponent() : mpEndComponent;
   mpEndExpandableConnectorTreeView = 0;
   if (mpEndComponent->isExpandableConnector() || (mpEndRootComponent && mpEndRootComponent->isExpandableConnector())) {
     mpEndExpandableConnectorTreeModel = new ExpandableConnectorTreeModel(this);
@@ -2185,7 +2164,7 @@ CreateOrEditTransitionDialog::CreateOrEditTransitionDialog(GraphicsView *pGraphi
   // Create the buttons
   mpOkButton = new QPushButton(Helper::ok);
   mpOkButton->setAutoDefault(true);
-  if (mpGraphicsView->getModelWidget()->getLibraryTreeItem()->isSystemLibrary() || mpGraphicsView->isVisualizationView()) {
+  if (mpGraphicsView->getModelWidget()->getLibraryTreeItem()->isSystemLibrary()) {
     mpOkButton->setDisabled(true);
   }
   connect(mpOkButton, SIGNAL(clicked()), SLOT(createOrEditTransition()));
