@@ -49,6 +49,7 @@
 #include "LibraryTreeWidget.h"
 #include "OMSimulator.h"
 
+#include <QOpenGLContext>
 #include <QGraphicsView>
 #include <QGraphicsScene>
 #include <QStatusBar>
@@ -109,6 +110,7 @@ private:
   Element *mpClickedState;
   bool mIsMovingComponentsAndShapes;
   bool mRenderingLibraryPixmap;
+  bool mSharpLibraryPixmap;
   QList<Element*> mElementsList;
   // A list of components that are not deleted but are removed from scene.
   QList<Element*> mOutOfSceneElementsList;
@@ -148,15 +150,20 @@ private:
   QAction *mpRotateAntiClockwiseAction;
   QAction *mpFlipHorizontalAction;
   QAction *mpFlipVerticalAction;
+  QAction *mpCreateConnectorAction;
+  QAction *mpCancelConnectionAction;
   QAction *mpSetInitialStateAction;
   QAction *mpCancelTransitionAction;
   // scene->items().contains(...) involves sorting on each items() call, avoid it
   QSet<QGraphicsItem*> mAllItems;
 public:
-  GraphicsView(StringHandler::ViewType viewType, ModelWidget *pModelWidget, bool visualizationView = false);
+  GraphicsView(StringHandler::ViewType viewType, ModelWidget *pModelWidget);
   bool mSkipBackground; /* Do not draw the background rectangle */
+  QPointF mContextMenuStartPosition;
+  bool mContextMenuStartPositionValid;
   StringHandler::ViewType getViewType() {return mViewType;}
   ModelWidget* getModelWidget() {return mpModelWidget;}
+  void setIsVisualizationView(bool visualizationView);
   bool isVisualizationView() {return mVisualizationView;}
   void setExtentRectangle(const QRectF rectangle);
   void setIsCustomScale(bool enable) {mIsCustomScale = enable;}
@@ -189,6 +196,8 @@ public:
   bool isMovingComponentsAndShapes() {return mIsMovingComponentsAndShapes;}
   void setRenderingLibraryPixmap(bool renderingLibraryPixmap) {mRenderingLibraryPixmap = renderingLibraryPixmap;}
   bool isRenderingLibraryPixmap() {return mRenderingLibraryPixmap;}
+  void setSharpLibraryPixmap(bool sharpLibraryPixmap) {mSharpLibraryPixmap = sharpLibraryPixmap;}
+  bool useSharpLibraryPixmap() {return mSharpLibraryPixmap;}
   QList<ShapeAnnotation*> getShapesList() {return mShapesList;}
   QList<ShapeAnnotation*> getInheritedShapesList() {return mInheritedShapesList;}
   QAction* getManhattanizeAction() {return mpManhattanizeAction;}
@@ -205,6 +214,7 @@ public:
   QAction* getRotateAntiClockwiseAction() {return mpRotateAntiClockwiseAction;}
   QAction* getFlipHorizontalAction() {return mpFlipHorizontalAction;}
   QAction* getFlipVerticalAction() {return mpFlipVerticalAction;}
+  bool performElementCreationChecks(LibraryTreeItem *pLibraryTreeItem, QString *name, QString *defaultPrefix);
   bool addComponent(QString className, QPointF position);
   void addComponentToView(QString name, LibraryTreeItem *pLibraryTreeItem, QString annotation, QPointF position,
                           ElementInfo *pComponentInfo, bool addObject, bool openingClass, bool emitComponentAdded);
@@ -218,6 +228,7 @@ public:
   void deleteElementFromOutOfSceneList(Element *pElement) {mOutOfSceneElementsList.removeOne(pElement);}
   void deleteInheritedElementFromList(Element *pElement) {mInheritedElementsList.removeOne(pElement);}
   Element* getElementObject(QString elementName);
+  QString getUniqueElementName(const QString &nameStructure, const QString &name, QString *defaultName);
   QString getUniqueElementName(QString elementName, int number = 0);
   bool checkElementName(QString elementName);
   QList<Element*> getElementsList() {return mElementsList;}
@@ -293,6 +304,7 @@ public:
   void addItem(QGraphicsItem *pGraphicsItem);
   void removeItem(QGraphicsItem *pGraphicsItem);
   void fitInViewInternal();
+  void emitResetDynamicSelect();
 private:
   void createActions();
   bool isClassDroppedOnItself(LibraryTreeItem *pLibraryTreeItem);
@@ -354,6 +366,8 @@ signals:
   void keyPressShiftRight();
   void keyPressCtrlRight();
   void keyPressDuplicate();
+  void updateDynamicSelect(double time);
+  void resetDynamicSelect();
 public slots:
   void addConnection(Element *pComponent);
   void removeCurrentConnection();
@@ -381,6 +395,8 @@ public slots:
   void rotateAntiClockwise();
   void flipHorizontal();
   void flipVertical();
+  void createConnector();
+  void cancelConnection();
   void setInitialState();
   void cancelTransition();
 protected:
@@ -429,6 +445,8 @@ private:
   QFrame *mpBottomFrame;
   QPushButton *mpCreateModelButton;
   QPushButton *mpOpenModelButton;
+  QPushButton *mpSystemLibrariesButton;
+  QPushButton *mpInstallLibraryButton;
 public slots:
   void addLatestNewsListItems();
 private slots:
@@ -517,6 +535,7 @@ public:
   BaseEditor* getEditor() {return mpEditor;}
   void setModelClassPathLabel(QString path) {mpModelClassPathLabel->setText(path);}
   void setModelFilePathLabel(QString path) {mpModelFilePathLabel->setText(path);}
+  QVBoxLayout* getMainLayout() {return mpMainLayout;}
   bool isLoadedWidgetComponents() {return mCreateModelWidgetComponents;}
   void addInheritedClass(LibraryTreeItem *pLibraryTreeItem) {mInheritedClassesList.append(pLibraryTreeItem);}
   void removeInheritedClass(LibraryTreeItem *pLibraryTreeItem) {mInheritedClassesList.removeOne(pLibraryTreeItem);}
@@ -553,7 +572,6 @@ public:
   void clearSelection();
   void updateClassAnnotationIfNeeded();
   void updateModelText();
-  void updateModelicaTextManually(QString contents);
   void updateUndoRedoActions();
   bool writeCoSimulationResultFile(QString fileName);
   bool writeVisualXMLFile(QString fileName, bool canWriteVisualXMLFile = false);
@@ -564,7 +582,10 @@ public:
   void dissociateBusWithConnector(QString busName, QString connectorName);
   void associateBusWithConnectors(QString busName);
   QList<QVariant> toOMSensData();
-  void createOMSimulatorUndoCommand(const QString &commandText, const bool doSnapShot = true);
+  void createOMSimulatorUndoCommand(const QString &commandText, const bool doSnapShot = true, const bool switchToEdited = true,
+                                    const QString oldEditedCref = QString(""), const QString newEditedCref = QString(""));
+  void createOMSimulatorRenameModelUndoCommand(const QString &commandText, const QString &cref, const QString &newCref);
+  void processPendingModelUpdate();
 private:
   ModelWidgetContainer *mpModelWidgetContainer;
   LibraryTreeItem *mpLibraryTreeItem;
@@ -591,6 +612,7 @@ private:
   bool mDiagramViewLoaded;
   bool mConnectionsLoaded;
   bool mCreateModelWidgetComponents;
+  QVBoxLayout *mpMainLayout;
   QString mIconAnnotationString;
   QString mDiagramAnnotationString;
   bool mExtendsModifiersLoaded;
@@ -602,6 +624,7 @@ private:
   QMap<int, IconDiagramMap> mInheritedClassesDiagramMap;
   QList<ElementInfo*> mElementsList;
   QStringList mElementsAnnotationsList;
+  QTimer mUpdateModelTimer;
 
   void createUndoStack();
   void handleCanUndoRedoChanged();
@@ -635,6 +658,7 @@ private slots:
   void showIconView(bool checked);
   void showDiagramView(bool checked);
   void showTextView(bool checked);
+  void updateModel();
 public slots:
   void makeFileWritAble();
   void showDocumentationView();
@@ -685,6 +709,7 @@ public slots:
   void saveAsModelWidget();
   void saveTotalModelWidget();
   void printModel();
+  void fitToDiagram();
   void showSimulationParams();
   void alignInterfaces();
   void addSystem();
