@@ -34,6 +34,12 @@
 
 //! @brief Contains functions used for parsing results obtained from OpenModelica Compiler.
 
+#define ANTLR4CPP_STATIC
+#include "antlr4-runtime.h"
+#include "modelicaLexer.h"
+#include "modelicaParser.h"
+#include "modelicaBaseListener.h"
+
 #include "StringHandler.h"
 #include "Helper.h"
 #include "Utilities.h"
@@ -886,73 +892,78 @@ QString StringHandler::removeFirstLastSingleQuotes(QString value)
   return value;
 }
 
+/*!
+ * \brief StringHandler::getStrings
+ * Splits a comma-separated string into a list of strings while preserving
+ * Modelica expressions such as strings, arrays and records.
+ * \param value
+ * \return
+ */
 QStringList StringHandler::getStrings(QString value)
 {
-  return getStrings(value, '{', '}');
-}
+  QStringList res;
+  int blocks = 0;
+  bool escaped = false;
+  char str_char = 0;
+  int start = 0;
+  int n = 0;
 
-QStringList StringHandler::getStrings(QString value, char start, char end)
-{
-  QStringList list;
-  bool mask = false;
-  bool inString = false;
-  char StringEnd = '\0';
-  int begin = 0;
-  int ele = 0;
+  for (auto &c: value) {
+    ++n;
 
-  for (int i = 0 ; i < value.length() ; i++)
-  {
-    if (inString)
-    {
-      if (mask)
-      {
-        mask = false;
-      }
-      else
-      {
-        if (value.at(i) == '\\')
-        {
-          mask = true;
-        }
-        else if (value.at(i) == StringEnd)
-        {
-          inString = false;
-        }
+    if (escaped) {
+      escaped = false;
+      continue;
+    } else if (str_char) {
+      if (c == str_char) {
+        str_char = 0;
+      } else if (c == '\\') {
+        escaped = true;
       }
+      continue;
     }
-    else
-    {
-      if (value.at(i) == '"')
-      {
-          StringEnd = '"';
-          inString = true;
-      }
-      else if (value.at(i) == '\'')
-      {
-          StringEnd = '\'';
-          inString = true;
-      }
-      else if (value.at(i) == ',')
-      {
-        if (ele == 0)
-        {
-          list.append(value.mid(begin,i-begin).trimmed());
-          begin = i+1;
+
+    switch (c.unicode()) {
+      case '{':
+      case '(':
+      case '[':
+        ++blocks;
+        break;
+
+      case '}':
+      case ')':
+      case ']':
+        --blocks;
+        break;
+
+      case '\\':
+        escaped = true;
+        break;
+
+      case '"':
+      case '\'':
+        str_char = c.unicode();
+        break;
+
+      case ',':
+        if (blocks == 0) {
+          res.append(value.mid(start, n-1).trimmed());
+          start += n;
+          n = 0;
         }
-      }
-      else if (value.at(i) == start)
-      {
-        ele++;
-      }
-      else if (value.at(i) == end)
-      {
-        ele--;
-      }
+        break;
     }
   }
-  list.append(value.mid(begin,value.length()-begin).trimmed());
 
-  return list;
+  if (n > 0) {
+    // Append the rest of the string if there's anything left.
+    res.append(value.mid(start).trimmed());
+  } else if (!value.isEmpty() && value[value.size()-1] == ',') {
+    // Append an empty string if the string ends with ,
+    res.append(QString());
+  }
+
+  return res;
 }
 
 /*!
@@ -1077,8 +1088,7 @@ QString StringHandler::escapeString(QString value)
   QString res;
   value = value.trimmed();
   for (int i = 0; i < value.length(); i++) {
-    switch (value[i].toAscii())
-	{
+    switch (value[i].toAscii()) {
       case '"':  res.append("\\\"");   break;
       case '\\': res.append("\\\\");   break;
       case '\a': res.append("\\a");    break;
@@ -1099,8 +1109,7 @@ QString StringHandler::escapeStringQuotes(QString value)
   QString res;
   value = value.trimmed();
   for (int i = 0; i < value.length(); i++) {
-    switch (value[i].toAscii())
-    {
+    switch (value[i].toAscii()) {
       case '"':  res.append("\\\"");   break;
       default:   res.append(value[i]); break;
     }
@@ -1108,6 +1117,31 @@ QString StringHandler::escapeStringQuotes(QString value)
   return res;
 }
 
+/*!
+ * \brief StringHandler::escapeTextAnnotationString
+ * Escapes the text annotation string without n and r.
+ * \param value
+ * \return
+ */
+QString StringHandler::escapeTextAnnotationString(QString value)
+{
+  QString res;
+  value = value.trimmed();
+  for (int i = 0; i < value.length(); i++) {
+    switch (value[i].toAscii()) {
+      case '"':  res.append("\\\"");   break;
+      case '\\': res.append("\\\\");   break;
+      case '\a': res.append("\\a");    break;
+      case '\b': res.append("\\b");    break;
+      case '\f': res.append("\\f");    break;
+      case '\t': res.append("\\t");    break;
+      case '\v': res.append("\\v");    break;
+      default:   res.append(value[i]); break;
+    }
+  }
+  return res;
+}
+
 #define CONSUME_CHAR(value,res,i) \
   if (value.at(i) == '\\') { \
   i++; \
@@ -1251,7 +1285,7 @@ QString StringHandler::getSaveFileName(QWidget* parent, const QString &caption,
   }
   else
   {
-    dir_str = mLastOpenDir.isEmpty() ? QDir::homePath() : mLastOpenDir;
+    dir_str = StringHandler::getLastOpenDirectory();
   }
 
   /* Add the extension with purposedName because if the directory with the same name exists then
@@ -1283,14 +1317,12 @@ QString StringHandler::getSaveFileName(QWidget* parent, const QString &caption,
 #else
     Q_UNUSED(defaultSuffix);
 #endif
-    mLastOpenDir = fileInfo.absolutePath();
-    return fileName;
+    StringHandler::setLastOpenDirectory(fileInfo.absolutePath());
   }
-  return "";
+  return fileName;
 }
 
-QString StringHandler::getSaveFolderName(QWidget* parent, const QString &caption, QString * dir, const QString &filter,
-                                         QString * selectedFilter, const QString *proposedName)
+QString StringHandler::getSaveFolderName(QWidget* parent, const QString &caption, QString * dir, const QString &filter, QString * selectedFilter, const QString *proposedName)
 {
   QString dir_str;
   QString folderName;
@@ -1298,7 +1330,7 @@ QString StringHandler::getSaveFolderName(QWidget* parent, const QString &caption
   if (dir) {
     dir_str = *dir;
   } else {
-    dir_str = mLastOpenDir.isEmpty() ? QDir::homePath() : mLastOpenDir;
+    dir_str = StringHandler::getLastOpenDirectory();
   }
 
   QString proposedFileName = *proposedName;
@@ -1307,6 +1339,9 @@ QString StringHandler::getSaveFolderName(QWidget* parent, const QString &caption
   } else {
     folderName = QFileDialog::getSaveFileName(parent, caption, dir_str, filter, selectedFilter);
   }
+  if (!folderName.isEmpty()) {
+    StringHandler::setLastOpenDirectory(folderName);
+  }
   return folderName;
 }
 
@@ -1317,11 +1352,11 @@ QString StringHandler::getOpenFileName(QWidget* parent, const QString &caption,
   if (dir) {
     dir_str = *dir;
   } else {
-    dir_str = mLastOpenDir.isEmpty() ? QDir::homePath() : mLastOpenDir;
+    dir_str = StringHandler::getLastOpenDirectory();
   }
 
   QString fileName = "";
-#ifdef WIN32
+#if defined(_WIN32)
   fileName = QFileDialog::getOpenFileName(parent, caption, dir_str, filter, selectedFilter);
 #else
   Q_UNUSED(selectedFilter)
@@ -1338,7 +1373,7 @@ QString StringHandler::getOpenFileName(QWidget* parent, const QString &caption,
 #endif
   if (!fileName.isEmpty()) {
     QFileInfo fileInfo(fileName);
-    mLastOpenDir = fileInfo.absolutePath();
+    StringHandler::setLastOpenDirectory(fileInfo.absolutePath());
   }
   return fileName;
 }
@@ -1350,11 +1385,11 @@ QStringList StringHandler::getOpenFileNames(QWidget* parent, const QString &capt
   if (dir) {
     dir_str = *dir;
   } else {
-    dir_str = mLastOpenDir.isEmpty() ? QDir::homePath() : mLastOpenDir;
+    dir_str = StringHandler::getLastOpenDirectory();
   }
 
   QStringList fileNames;
-#ifdef WIN32
+#if defined(_WIN32)
   fileNames = QFileDialog::getOpenFileNames(parent, caption, dir_str, filter, selectedFilter);
 #else
   Q_UNUSED(selectedFilter);
@@ -1371,7 +1406,7 @@ QStringList StringHandler::getOpenFileNames(QWidget* parent, const QString &capt
 #endif
   if (!fileNames.isEmpty()) {
     QFileInfo fileInfo(fileNames.at(0));
-    mLastOpenDir = fileInfo.absolutePath();
+    StringHandler::setLastOpenDirectory(fileInfo.absolutePath());
   }
   return fileNames;
 }
@@ -1383,15 +1418,14 @@ QString StringHandler::getExistingDirectory(QWidget *parent, const QString &capt
   if (dir) {
     dir_str = *dir;
   } else {
-    dir_str = mLastOpenDir.isEmpty() ? QDir::homePath() : mLastOpenDir;
+    dir_str = StringHandler::getLastOpenDirectory();
   }
 
   QString dirName = QFileDialog::getExistingDirectory(parent, caption, dir_str, QFileDialog::ShowDirsOnly);
   if (!dirName.isEmpty()) {
-    mLastOpenDir = dirName;
-    return dirName;
+    StringHandler::setLastOpenDirectory(dirName);
   }
-  return "";
+  return dirName;
 }
 
 void StringHandler::setLastOpenDirectory(QString lastOpenDirectory)
@@ -1401,7 +1435,7 @@ void StringHandler::setLastOpenDirectory(QString lastOpenDirectory)
 
 QString StringHandler::getLastOpenDirectory()
 {
-  return mLastOpenDir;
+  return mLastOpenDir.isEmpty() ? QDir::homePath() : mLastOpenDir;
 }
 
 QStringList StringHandler::getAnnotation(QString componentAnnotation, QString annotationName)
@@ -1410,7 +1444,7 @@ QStringList StringHandler::getAnnotation(QString componentAnnotation, QString an
   if (componentAnnotation.isEmpty()) {
     return QStringList();
   }
-  QStringList annotations = StringHandler::getStrings(componentAnnotation, '(', ')');
+  QStringList annotations = StringHandler::getStrings(componentAnnotation);
   foreach (QString annotation, annotations) {
     if (annotation.startsWith(annotationName)) {
       annotation = annotation.mid(QString(annotationName).length());
@@ -1431,7 +1465,7 @@ QString StringHandler::getPlacementAnnotation(QString componentAnnotation)
   if (componentAnnotation.isEmpty()) {
     return "";
   }
-  QStringList annotations = StringHandler::getStrings(componentAnnotation, '(', ')');
+  QStringList annotations = StringHandler::getStrings(componentAnnotation);
   foreach (QString annotation, annotations) {
     if (annotation.startsWith("Placement")) {
       QString placementAnnotation = StringHandler::removeFirstLastParentheses(annotation);
@@ -1638,7 +1672,7 @@ bool StringHandler::naturalSortForResultVariables(const QString &s1, const QStri
   return StringHandler::naturalSort(s3, s4);
 }
 
-#ifdef WIN32
+#if defined(_WIN32)
 /*!
  * \brief StringHandler::simulationProcessEnvironment
  * Returns the environment for simulation process.
@@ -1924,11 +1958,84 @@ QString StringHandler::insertClassAtPosition(QString parentClassText, QString ch
  * \brief StringHandler::number
  * Helper for QString::number with default precision of 16 instead of 6.
  * \param value
+ * \param hint - default "" otherwise previous value to get a hint on how to format the new one
  * \param format
  * \param precision
  * \return
  */
-QString StringHandler::number(double value, char format, int precision)
+QString StringHandler::number(double value, QString hint, char format, int precision)
 {
-  return QString::number(value, format, precision);
+  // we have a hint, see if we can use it to display the number in a similar fashion
+  if (hint.contains("e", Qt::CaseInsensitive)) {
+    // we have an e in the hint, attempt to shorten the number!
+    return QString::number(value, format, QLocale::FloatingPointShortest);
+  } else {
+    return QString::number(value, format, precision);
+  }
+}
+
+static std::string cmt = "";
+
+class ModelicaCommentListener : public openmodelica::modelicaBaseListener {
+    void exitComment(openmodelica::modelicaParser::CommentContext *ctx) override {
+        cmt = ctx->getText();
+    }
+};
+
+/*!
+ * \brief StringHandler::getModelicaComment
+ * Helper for QString::getModelicaComment
+ * \param element
+ * \return comment
+ */
+QString StringHandler::getModelicaComment(QString element)
+{
+  cmt = "";
+  std::string s = element.toStdString();
+  antlr4::ANTLRInputStream input(s);
+  openmodelica::modelicaLexer lexer(&input);
+  antlr4::CommonTokenStream tokens(&lexer);
+  openmodelica::modelicaParser parser(&tokens);
+  antlr4::tree::ParseTree* tree = parser.argument();
+  ModelicaCommentListener listener;
+  antlr4::tree::ParseTreeWalker::DEFAULT.walk(&listener, tree);
+  if (cmt.size() > 1)
+  {
+    QString q;
+    q = q.fromStdString(cmt);
+    return removeFirstLastQuotes(q);
+  }
+  return element;
+}
+
+/*!
+ * \brief StringHandler::convertSemVertoReadableString
+ * Converts the semver to user friendly string.
+ * https://semver.org/#semantic-versioning-specification-semver
+ * For example, "4.0.0+maint.om" becomes "4.0.0 (post-release build maint.om)"
+ * \param semver
+ * \return
+ */
+QString StringHandler::convertSemVertoReadableString(const QString &semver)
+{
+  QStringList vars;
+  QString release;
+  QString version = semver;
+  if (semver.contains('+')) {
+    vars = semver.split('+');
+    release = "post-release";
+  } else {
+    vars = semver.split('-');
+    release = "pre-release";
+  }
+
+  if (!vars.isEmpty()) {
+    version = vars.at(0);
+    if (vars.length() > 1) {
+      vars.removeFirst();
+      version = QString("%1 (%2 build %3)").arg(version, release, vars.join(""));
+    }
+  }
+
+  return version;
 }
