@@ -160,7 +160,7 @@ namespace IAEX
     // 2005-12-01 AF, Added try-catch
     try
     {
-      if(filename_ != QString::null)
+      if(!filename_.isNull())
         open( filename_, readmode );
     }
     catch( exception &e )
@@ -666,7 +666,7 @@ namespace IAEX
 
     // save the image temporary to the harddrive
     QImageWriter writer( name, "png" );
-    writer.setDescription( tr("Temporary OMNotebook image") );
+    writer.setText("Description", tr("Temporary OMNotebook image") );
     writer.setQuality( 100 );
     writer.write( *image );
 
@@ -945,13 +945,7 @@ namespace IAEX
    */
   void CellDocument::mouseClickedOnCell(Cell *clickedCell)
   {
-
-    // 2006-04-25, AF
-    if( lastClickedCell_ == clickedCell )
-      return;
-    else
-      lastClickedCell_ = clickedCell;
-
+    lastClickedCell_ = clickedCell;
 
     //Deselect all selection
     clearSelection();
