@@ -30,14 +30,13 @@
  */
 
 #include "Connection.h"
-#include "ssd/ConnectionGeometry.h"
 #include "Logging.h"
+#include "ssd/ConnectionGeometry.h"
 #include "ssd/Tags.h"
 
 #include <cstring>
 #include <iostream>
 
-
 oms::Connection::Connection(const oms::ComRef& conA, const oms::ComRef& conB, oms_connection_type_enu_t type)
 {
   std::string str;
@@ -113,9 +112,9 @@ oms_status_enu_t oms::Connection::exportToSSD(pugi::xml_node &root) const
 {
   pugi::xml_node node;
   if(type == oms_connection_single)
-    node = root.append_child(oms::ssd::ssd_connection);
+    node = root.append_child(oms::ssp::Draft20180219::ssd::connection);
   else if(type == oms_connection_bus || type == oms_connection_tlm)
-    node = root.append_child(oms::bus_connection);
+    node = root.append_child(oms::ssp::Draft20180219::bus_connection);
 
   ComRef startConnectorRef(conA);
   ComRef startElementRef = startConnectorRef.pop_front();
@@ -140,12 +139,12 @@ oms_status_enu_t oms::Connection::exportToSSD(pugi::xml_node &root) const
   return oms_status_ok;
 }
 
-void oms::Connection::setGeometry(const oms::ssd::ConnectionGeometry* newGeometry)
+void oms::Connection::setGeometry(const oms::ssd::ConnectionGeometry* newGeometry, bool inverse)
 {
   oms::ssd::ConnectionGeometry* geometry_ = reinterpret_cast<oms::ssd::ConnectionGeometry*>(this->geometry);
   if (geometry_)
     delete geometry_;
-  geometry_ = new oms::ssd::ConnectionGeometry(*newGeometry);
+  geometry_ = new oms::ssd::ConnectionGeometry(*newGeometry, inverse);
   this->geometry = reinterpret_cast<ssd_connection_geometry_t*>(geometry_);
 }
 
@@ -172,6 +171,11 @@ void oms::Connection::setTLMParameters(double delay, double alpha, double linear
   tlmparameters->angularimpedance = angualrimpedance;
 }
 
+bool oms::Connection::isStrictEqual(const oms::ComRef& signalA, const oms::ComRef& signalB) const
+{
+  return signalA == oms::ComRef(this->conA) && signalB == oms::ComRef(this->conB);
+}
+
 bool oms::Connection::isEqual(const oms::ComRef& signalA, const oms::ComRef& signalB) const
 {
   return (signalA == oms::ComRef(this->conA) && signalB == oms::ComRef(this->conB)) || (signalA == oms::ComRef(this->conB) && signalB == oms::ComRef(this->conA));
@@ -184,7 +188,73 @@ bool oms::Connection::isEqual(const oms::Connection& connection) const
   return isEqual(conA_, conB_);
 }
 
-bool oms::Connection::containsSignal(const oms::ComRef& signal)
+bool oms::Connection::containsSignal(const oms::ComRef& signal) const
 {
   return signal.isRootOf(oms::ComRef(this->conA)) || signal.isRootOf(oms::ComRef(this->conB));
 }
+
+bool oms::Connection::containsSignalB(const oms::ComRef& signal) const
+{
+  return signal.isRootOf(oms::ComRef(this->conB));
+}
+
+bool oms::Connection::isValid(const ComRef& crefA, const ComRef& crefB, const Connector& conA, const Connector& conB)
+{
+  bool connectorA, connectorB;
+
+  // Check connector A
+  if (crefA.isValidIdent()) // this is a system
+  {
+    // Connector A of a systems must be input or parameter
+    connectorA = conA.isInput() || conA.isParameter();
+  }
+  else // this is an element
+  {
+    // Connector A of an element must be output, calculated parameter, or inout
+    // TODO: check for inout, neither FMI-1.0 nor FMI-2.0 do support inout
+    connectorA = conA.isOutput() || conA.isCalculatedParameter();
+  }
+
+  // Check connector B
+  if (crefB.isValidIdent()) // this is a system
+  {
+    // Connector B of a systems must be output or calculated parameter
+    connectorB = conB.isOutput() || conB.isCalculatedParameter();
+  }
+  else // this is an element
+  {
+    // Connector A of an element must be input, parameter, or inout
+    // TODO: check for inout, neither FMI-1.0 nor FMI-2.0 do support inout
+    connectorB = conB.isParameter() || conB.isInput();
+  }
+
+  // both connectors must be valid in order to make the connection valid
+  return connectorA && connectorB;
+}
+
+oms_status_enu_t oms::Connection::rename(const ComRef& cref, const ComRef& newCref)
+{
+  oms::ComRef tailA(getSignalA());
+  const oms::ComRef frontA = tailA.pop_front();
+
+  if (frontA == cref)
+  {
+    std::string str(newCref + tailA);
+    delete [] this->conA;
+    this->conA = new char[str.size()+1];
+    strcpy(this->conA, str.c_str());
+  }
+
+  oms::ComRef tailB(getSignalB());
+  const oms::ComRef frontB = tailB.pop_front();
+
+  if (frontB == cref)
+  {
+    std::string str(newCref + tailB);
+    delete [] this->conB;
+    this->conB = new char[str.size()+1];
+    strcpy(this->conB, str.c_str());
+  }
+
+  return oms_status_ok;
+}
